Commands
========

**********
tom_alerts
**********

runbrokerquery.py - Runs saved alert queries and saves the results as Targets.

****************
tom_dataproducts
****************

downloaddata.py - Downloads available data for all completed observations.

updatereduceddata - Gets and updates time-series data for alert-generated targets from the original alert source. Can optionally specify a target id.


****************
tom_dataproducts
****************

runcadencestrategy.py - Entry point for running cadence strategies.

updatestatus.py - Updates the status of each observation request in the TOM. Target id can be specified to update the status for all observations for a single target.
